ods html close;
ods listing;

options nocenter ps=10000 ls=160 nonumber nodate;


proc import datafile='c:\temp\simulated_ccts.csv'
        out=ccts
        dbms=csv
        replace;
run;



/* 
show contents of sas dataset ccts
*/

proc contents data=ccts;
run;

 
title 'Means (proportions at each time point and number missing' ;



proc means data=ccts n mean;
 class trt;
 var CS1 CS2 CS3 CS4 CS5 CS6;
 run;



/* create long dataset for proc genmod */

 data ccts_long(drop= CS1 CS2 CS3 CS4 CS5 CS6  ); 
   set ccts ;
 
 CS =  CS1;
 time_=1;
 output;

 CS =  CS2;
 time_=2;
 output;

CS =  CS3;
 time_=3;
 output;

 CS =  CS4;
 time_=4;
 output;

 CS =  CS5;
 time_=5;
 output;

 CS =  CS6;
 time_=6;
 output;
run;
 
title 'Usual GEE with observed data';

 proc genmod desc data= ccts_long;
 class id  time_/ desc; 
 model CS=   trt / link=logit dist=binomial;
  repeated subject=id / corr=ar corrw WITHINSUBJECT=time_;
 run;




/* Imputation */


proc sort data=ccts ;
 by trt;
run;


title 'multivariate normal imputation without cross products';

proc mi data=ccts out=ccts_mvn_imp1  seed=5556 nimpute=30 ; 
by trt;
   var  CS1 CS2 CS3 CS4 CS5 CS6;
run;


proc sort data=ccts_mvn_imp1;
 by _imputation_;
 run;

 data ccts_long_mvn_imp1(drop= CS1 CS2 CS3 CS4 CS5 CS6 ); 
   set ccts_mvn_imp1 ;
 

 CS =  CS1;
 time_=1;
 output;

 CS =  CS2;
 time_=2;
 output;

CS =  CS3;
 time_=3;
 output;

 CS =  CS4;
 time_=4;
 output;

 CS =  CS5;
 time_=5;
 output;

 CS =  CS6;
 time_=6;
 output;
run;



ods listing close;  /* suppress printing of GEE results for 30 imputations */

/* GEE with mean and variance function equal to binary since imputing values not
0 or 1 */

proc genmod data= ccts_long_mvn_imp1;
   by _imputation_ ;
 class id  time_ / desc ; 
 a = _MEAN_;
   variance var = a*(1-a);
 model CS=    trt / link=logit dist=n noscale covb;
  repeated subject=id / corr=ar corrw  WITHINSUBJECT=time_ ;
  ods output GEEEmpPEst = parms_mvn_imp1   ; 
 run;

 ods listing;


 proc mianalyze parms=parms_mvn_imp1  ;
   modeleffects Intercept  trt;
run;





title 'multivariate normal imputation with cross products';

data ccts_cross;
 set ccts ;

 CS12=CS1*CS2;
 CS13=CS1*CS3;
 CS14=CS1*CS4;
 CS15=CS1*CS5;
 CS16=CS1*CS6;

 CS23=CS2*CS3;
 CS24=CS2*CS4;
 CS25=CS2*CS5;
 CS26=CS2*CS6;

 CS34=CS3*CS4;
 CS35=CS3*CS5;
 CS36=CS3*CS6;

 CS45=CS4*CS5;
 CS46=CS4*CS6;

 CS56=CS5*CS6;

 run;

 
 
proc mi data=ccts_cross out=ccts_cross_mvn_imp  seed=5556 nimpute=30 ; 
by trt;
   var  CS1 CS2 CS3 CS4 CS5 CS6
 CS12 CS13 CS14 CS15 CS16 CS23 CS24 CS25 CS26 CS34 CS35 CS36 CS45 CS46 CS56 ;
run;


proc sort data=ccts_cross_mvn_imp;
 by _imputation_;
 run;

 data ccts_long_cross_mvn_imp(drop= CS1 CS2 CS3 CS4 CS5 CS6 ); 
   set ccts_cross_mvn_imp ;
 

 CS =  CS1;
 time_=1;
 output;

 CS =  CS2;
 time_=2;
 output;

CS =  CS3;
 time_=3;
 output;

 CS =  CS4;
 time_=4;
 output;

 CS =  CS5;
 time_=5;
 output;

 CS =  CS6;
 time_=6;
 output;
run;

ods listing close;
 
proc genmod data= ccts_long_cross_mvn_imp;
   by _imputation_ ;
 class id  time_ / desc  ; 
 a = _MEAN_;
   variance var = a*(1-a);
 model CS=     trt / link=logit dist=n noscale covb;
  repeated subject=id / corr=ar corrw  WITHINSUBJECT=time_ ;
  ods output GEEEmpPEst = parms_mvn_imp2   ; 
 run;

ods listing;

 
 proc mianalyze parms= parms_mvn_imp2  ;
   modeleffects Intercept     trt;
run;



title 'fcs imputation without cross products';


proc mi data=ccts out=ccts_fcs_imp1  seed=5556 nimpute=30 ; 
by trt;
 class CS1 CS2 CS3 CS4 CS5 CS6;
  fcs logistic(CS1=CS2 CS3 CS4 CS5 CS6);
  fcs logistic(CS2=CS1 CS3 CS4 CS5 CS6);
  fcs logistic(CS3=CS1 CS2 CS4 CS5 CS6);
  fcs logistic(CS4=CS1 CS2 CS3 CS5 CS6);
  fcs logistic(CS5=CS1 CS2 CS3 CS4 CS6);
  fcs logistic(CS6=CS1 CS2 CS3 CS4 CS5);
   var  CS1 CS2 CS3 CS4 CS5 CS6;
run;

proc sort data=ccts_fcs_imp1;
 by _imputation_;
 run;

 data ccts_fcs_imp1(drop= CS1 CS2 CS3 CS4 CS5 CS6 ); 
   set ccts_fcs_imp1;
 

 CS =  CS1;
 time_=1;
 output;

 CS =  CS2;
 time_=2;
 output;

CS =  CS3;
 time_=3;
 output;

 CS =  CS4;
 time_=4;
 output;

 CS =  CS5;
 time_=5;
 output;

 CS =  CS6;
 time_=6;
 output;
run;

ods listing close;
 
proc genmod desc data= ccts_fcs_imp1;
   by _imputation_ ;
 class id  time_/ desc; 
 model CS=   trt / link=logit dist=binomial;
  repeated subject=id / corr=ar corrw WITHINSUBJECT=time_;
  ods output GEEEmpPEst = parms_fcs_imp1   ; 
 run;

 ods listing ;

 proc mianalyze parms=parms_fcs_imp1  ;
   modeleffects Intercept  trt;
run;







title 'fcs imputation with cross products';



proc mi data=ccts out=ccts_cross_fcs_imp  seed=5556 nimpute=30 ; 
by trt;
 class CS1 CS2 CS3 CS4 CS5 CS6;
  fcs logistic(CS1=CS2 CS3 CS4 CS5 CS6 
    CS2*CS3 CS2*CS4 CS2*CS5 CS2*CS6 CS3*CS4 CS3*CS5 CS3*CS6 CS4*CS5 CS4*CS6
    CS5*CS6);
  fcs logistic(CS2=CS1 CS3 CS4 CS5 CS6
    CS1*CS3 CS1*CS4 CS1*CS5 CS1*CS6 CS3*CS4 CS3*CS5 CS3*CS6 CS4*CS5 CS4*CS6
    CS5*CS6);
  fcs logistic(CS3=CS1 CS2 CS4 CS5 CS6
    CS1*CS2 CS1*CS4 CS1*CS5 CS1*CS6 CS2*CS4 CS2*CS5 CS2*CS6 CS4*CS5 CS4*CS6
    CS5*CS6);
  fcs logistic(CS4=CS1 CS2 CS3 CS5 CS6
    CS1*CS2 CS1*CS3 CS1*CS5 CS1*CS6 CS2*CS3 CS2*CS5 CS2*CS6 CS3*CS5 CS3*CS6
    CS5*CS6);
  fcs logistic(CS5=CS1 CS2 CS3 CS4 CS6
    CS1*CS2 CS1*CS3 CS1*CS4 CS1*CS6 CS2*CS3 CS2*CS4 CS2*CS6 CS3*CS4 CS3*CS6
    CS4*CS6);
  fcs logistic(CS6=CS1 CS2 CS3 CS4 CS5
    CS1*CS2 CS1*CS3 CS1*CS4 CS1*CS5 CS2*CS3 CS2*CS4 CS2*CS5 CS3*CS4 CS3*CS5
    CS4*CS5);
   var  CS1 CS2 CS3 CS4 CS5 CS6;
run;
 

proc sort data=ccts_cross_fcs_imp;
 by _imputation_;
 run;

 data ccts_cross_fcs_imp(drop= CS1 CS2 CS3 CS4 CS5 CS6 ); 
   set ccts_cross_fcs_imp;
 

 CS =  CS1;
 time_=1;
 output;

 CS =  CS2;
 time_=2;
 output;

CS =  CS3;
 time_=3;
 output;

 CS =  CS4;
 time_=4;
 output;

 CS =  CS5;
 time_=5;
 output;

 CS =  CS6;
 time_=6;
 output;
run;

ods listing close;
 
proc genmod desc data= ccts_cross_fcs_imp;
   by _imputation_ ;
 class id  time_/ desc; 
 model CS=   trt / link=logit dist=binomial;
  repeated subject=id / corr=ar corrw WITHINSUBJECT=time_;
  ods output GEEEmpPEst = parms_cross_fcs_imp   ; 
 run;

 ods listing;

 proc mianalyze parms=parms_cross_fcs_imp  ;
   modeleffects Intercept  trt;
run;

 
